var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
import { Component, Inject, trigger, style, state, transition, animate } from '@angular/core';
import { FormControl } from '@angular/forms';
import { SANDBOXES } from './shared/tokens';
import 'rxjs/add/operator/debounceTime';
import 'rxjs/add/operator/distinctUntilChanged';
import { StateService } from './shared/state.service';
import { EventManager } from "@angular/platform-browser";
export var AppComponent = (function () {
    function AppComponent(sandboxes, stateService, eventManager) {
        var _this = this;
        this.stateService = stateService;
        this.eventManager = eventManager;
        this.commandBarActive = false;
        this.filter = new FormControl();
        this.eventManager.addGlobalEventListener('window', 'keydown.control.o', function (e) {
            e.preventDefault();
        });
        this.eventManager.addGlobalEventListener('window', 'keyup.control.o', function () {
            _this.toggleCommandBar();
        });
        this.totalSandboxes = sandboxes.length;
        this.filteredSandboxes = this.filterSandboxes(sandboxes, this.stateService.getFilter());
        var _a = this.stateService.getSelectedSandboxAndScenarioKeys(), sandboxKey = _a.sandboxKey, scenarioKey = _a.scenarioKey;
        this.selectScenario(sandboxKey, scenarioKey);
        this.filter.setValue(this.stateService.getFilter());
        this.filter.valueChanges
            .debounceTime(300)
            .distinctUntilChanged()
            .subscribe(function (value) {
            _this.filteredSandboxes = _this.filterSandboxes(sandboxes, value);
            _this.stateService.setFilter(value);
            if (!value) {
                _this.selectScenario(null, null);
            }
        });
    }
    AppComponent.prototype.filterSandboxes = function (sandboxes, filter) {
        if (!filter) {
            return [];
        }
        return sandboxes
            .filter(function (sandbox) { return sandbox.name.toLowerCase().indexOf(filter.toLowerCase()) >= 0; })
            .sort(function (a, b) {
            var nameA = a.name.toUpperCase();
            var nameB = b.name.toUpperCase();
            if (nameA < nameB) {
                return -1;
            }
            if (nameA > nameB) {
                return 1;
            }
            return 0;
        });
    };
    AppComponent.prototype.toggleCommandBar = function () {
        this.commandBarActive = !this.commandBarActive;
    };
    AppComponent.prototype.selectScenario = function (sandboxKey, scenarioKey) {
        this.selectedSandboxAndScenarioKeys = { sandboxKey: sandboxKey, scenarioKey: scenarioKey };
        this.stateService.setSandboxAndScenarioKeys(this.selectedSandboxAndScenarioKeys);
    };
    AppComponent.prototype.onScenarioClick = function (sandboxKey, scenarioKey, e) {
        this.selectScenario(sandboxKey, scenarioKey);
        e.preventDefault();
    };
    AppComponent = __decorate([
        Component({
            selector: 'ap-root',
            animations: [
                trigger('flyInOut', [
                    state('true', style({ transform: 'translate(-50%, 0)' })),
                    transition('void => *', [
                        style({ transform: 'translate(-50%, -110%)' }),
                        animate(100)
                    ]),
                    transition('* => void', [
                        animate(100, style({ transform: 'translate(-50%, -110%)' }))
                    ])
                ])
            ],
            template: "\n    <div class=\"command-bar-shield\" *ngIf=\"commandBarActive\" (click)=\"toggleCommandBar()\"></div>\n    <div *ngIf=\"commandBarActive\" class=\"command-bar\" [@flyInOut]=\"commandBarActive\">\n      <input type=\"text\" name=\"filter\" placeholder=\"filter\" [formControl]=\"filter\" [apFocus]=\"commandBarActive\">\n      <div>\n        <div *ngFor=\"let sandbox of filteredSandboxes\">\n          <span class=\"sandbox\"\n                [class.selected]=\"selectedSandboxAndScenarioKeys.sandboxKey === sandbox.key\">\n            {{sandbox.prependText}}{{sandbox.name}}</span>\n          <div *ngFor=\"let scenario of sandbox.scenarios\">\n            <a class=\"scenario\"\n               (click)=\"onScenarioClick(sandbox.key, scenario.key, $event); toggleCommandBar()\"\n               [class.selected]=\"selectedSandboxAndScenarioKeys.scenarioKey === scenario.key && selectedSandboxAndScenarioKeys.sandboxKey === sandbox.key\">\n              {{scenario.description}}</a>\n          </div>\n        </div>\n      </div>\n    </div>\n    <section *ngIf=\"!selectedSandboxAndScenarioKeys.sandboxKey\" class=\"help-message\">\n      <div>\n        <template [ngIf]=\"totalSandboxes > 0\">\n          <p>The app has {{totalSandboxes}} sandboxed component{{totalSandboxes > 1 ? 's' : ''}} loaded.</p>\n        </template>\n        <template [ngIf]=\"totalSandboxes === 0\">\n          <p>The app does not have any sandboxed components.</p>\n        </template>\n        <p>Pick sandboxed components: <strong>ctrl + o</strong></p>\n      </div>\n    </section>\n    <section *ngIf=\"selectedSandboxAndScenarioKeys.sandboxKey\">\n      <ap-scenario [selectedSandboxAndScenarioKeys]=\"selectedSandboxAndScenarioKeys\"></ap-scenario>\n    </section>\n  ",
            styles: ["\n    :host {\n      font-family: sans-serif;\n      display: flex;\n      flex-direction: column; }\n      :host .command-bar-shield {\n        position: absolute;\n        width: 100%;\n        height: 100vh;\n        opacity: 0; }\n      :host .command-bar {\n        font-family: Menlo,Monaco,monospace;\n        position: absolute;\n        display: flex;\n        justify-content: center;\n        flex-direction: column;\n        align-items: center;\n        left: 50%;\n      }\n      :host .command-bar > input {\n        font-family: Menlo,Monaco,monospace;\n        width: 400px;\n        z-index: 1;\n        padding: 4px;\n        margin-top: 6px;\n        border: 1px solid #174a6c;\n        background-color: #3c3c3c;\n        font-size: 14pt;\n        color: #fff;\n      }\n      :host .command-bar > input::-webkit-input-placeholder {\n        color: #a9a9a9; }\n      :host .command-bar > input::-moz-focus-inner {\n        border: 0;\n        padding: 0; }\n      :host .command-bar > div {\n        margin-top: -39px;\n        width: 400px;\n        padding: 34px 14px 14px 14px;\n        background-color: #252526;\n        color: #fff;\n        box-shadow: 0 3px 8px 5px black;\n        font-size: 14pt;\n      }\n      :host .command-bar > div > div:first-child {\n        padding-top: 18px;\n      }\n      :host .command-bar > div a {\n        cursor: pointer; }\n      :host .command-bar .sandbox.selected, :host .command-bar .scenario.selected {\n        color: #0097fb; }\n      :host .command-bar .scenario {\n        font-size: .8em;\n        padding: 0 8px; }\n       \n      :host section {\n        border: 0;\n        width: 100%;\n        background-color: white; }\n        \n      :host section.help-message {\n        display: flex;\n        align-items: center;\n        justify-content: center; \n        height: 100vh; }\n      :host section.help-message > div {\n        max-width: 50%;\n        font-family: Menlo,Monaco,monospace; }\n  "]
        }),
        __param(0, Inject(SANDBOXES)), 
        __metadata('design:paramtypes', [Array, StateService, EventManager])
    ], AppComponent);
    return AppComponent;
}());
